==> maSigPro_1.20.0.zip: maSigPro/doc/maSigPro-tutorial.R <==
###################################################
### chunk number 1: 
###################################################
library(maSigPro) # load maSigPro library


###################################################
### chunk number 2: 
###################################################
data(data.abiotic)
data(edesign.abiotic)


###################################################
### chunk number 3: 
###################################################
edesign.abiotic


###################################################
### chunk number 4: 
###################################################
design <- make.design.matrix(edesign.abiotic, degree = 2)


###################################################
### chunk number 5: 
###################################################
design$groups.vector


###################################################
### chunk number 6: 
###################################################
fit <- p.vector(data.abiotic, design, Q = 0.05, MT.adjust = "BH", min.obs = 20)



###################################################
### chunk number 7: 
###################################################
tstep <- T.fit(fit, step.method = "backward", alfa = 0.05)


###################################################
### chunk number 8: 
###################################################
sigs <- get.siggenes(tstep, rsq = 0.6, vars = "groups")
sigs$summary


###################################################
### chunk number 9: 
###################################################
names(sigs$sig.genes)
names(sigs$sig.genes$ColdvsControl)


###################################################
### chunk number 10: venn1
###################################################
suma2Venn(sigs$summary[, c(2:4)])



###################################################
### chunk number 11: 
###################################################
STMDE66 <- data.abiotic[rownames(data.abiotic)=="STMDE66", ]


###################################################
### chunk number 12: plotGroups1
###################################################
PlotGroups (STMDE66, edesign = edesign.abiotic)


###################################################
### chunk number 13: plotGroups2
###################################################
PlotGroups (STMDE66, edesign = edesign.abiotic, show.fit = T, dis = design$dis, groups.vector = design$groups.vector)

==> maSigPro_1.22.0.zip: maSigPro/doc/maSigPro-tutorial.R <==
###################################################
### chunk number 1: 
###################################################
#line 60 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
library(maSigPro) # load maSigPro library


###################################################
### chunk number 2: 
###################################################
#line 101 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
data(data.abiotic)
data(edesign.abiotic)


###################################################
### chunk number 3: 
###################################################
#line 106 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
edesign.abiotic


###################################################
### chunk number 4: 
###################################################
#line 135 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
design <- make.design.matrix(edesign.abiotic, degree = 2)


###################################################
### chunk number 5: 
###################################################
#line 143 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
design$groups.vector


###################################################
### chunk number 6: 
###################################################
#line 155 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
fit <- p.vector(data.abiotic, design, Q = 0.05, MT.adjust = "BH", min.obs = 20)



###################################################
### chunk number 7: 
###################################################
#line 175 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
tstep <- T.fit(fit, step.method = "backward", alfa = 0.05)


###################################################
### chunk number 8: 
###################################################
#line 216 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
sigs <- get.siggenes(tstep, rsq = 0.6, vars = "groups")
sigs$summary


###################################################
### chunk number 9: 
###################################################
#line 223 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
names(sigs$sig.genes)
names(sigs$sig.genes$ColdvsControl)


###################################################
### chunk number 10: venn1
###################################################
#line 236 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
suma2Venn(sigs$summary[, c(2:4)])



###################################################
### chunk number 11: 
###################################################
#line 252 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
STMDE66 <- data.abiotic[rownames(data.abiotic)=="STMDE66", ]


###################################################
### chunk number 12: plotGroups1
###################################################
#line 256 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
PlotGroups (STMDE66, edesign = edesign.abiotic)


###################################################
### chunk number 13: plotGroups2
###################################################
#line 261 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpTgXbBQ/R.INSTALL641298e/maSigPro/inst/doc/maSigPro-tutorial.Rnw"
PlotGroups (STMDE66, edesign = edesign.abiotic, show.fit = T, dis = design$dis, groups.vector = design$groups.vector)
